==> haskell-memotrie-0.6.11-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MemoTrie
version:              0.6.11
visibility:           public
id:                   MemoTrie-0.6.11-FQPRkA2T7Od2jFvRE4Bzd9
key:                  MemoTrie-0.6.11-FQPRkA2T7Od2jFvRE4Bzd9
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  d80e7af38b86fa02cc13cfd4b24e9c50
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.11-FQPRkA2T7Od2jFvRE4Bzd9
depends:
    base-4.17.2.1 newtype-generics-0.6.2-BgNY5E414VkBMxQ83fXLSL

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.11-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MemoTrie
version:              0.6.11
visibility:           public
id:                   MemoTrie-0.6.11-EoqFf216gp4Cc23UtopLRB
key:                  MemoTrie-0.6.11-EoqFf216gp4Cc23UtopLRB
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  fb2636a8ad779f210c92ac76d8a342b8
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MemoTrie-0.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.11-EoqFf216gp4Cc23UtopLRB
depends:
    base-4.17.2.1 newtype-generics-0.6.2-6jv8BTaPEjlHIEiQG36B8n

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
